@@ -260,12 +260,17 @@ class OpenApiWrapper:
         else:
             return {"type": "object"}
 
-    def _get_dataclass_description(self, schema: DataclassProtocol) -> dict:
-        field_names = [field_.name for field_ in dataclasses.fields(schema) if field_.repr]
-        return {"type": "object", "properties": {
-            key: self._get_schema_description(sub_schema)
-            for key, sub_schema in typing.get_type_hints(schema).items() if key in field_names
-        }}
+    def _get_dataclass_description(self, schema: type[DataclassProtocol]) -> dict:
+        key_to_schema = {}
+        key_to_type_hint = typing.get_type_hints(schema)
+        for field_ in dataclasses.fields(schema):
+            if field_.repr:
+                try:
+                    key_to_schema[field_.name] = self._get_schema_description(field_.type)
+                except TypeError:
+                    key_to_schema[field_.name] = self._get_schema_description(key_to_type_hint[field_.name])
+        return {"type": "object", "properties": key_to_schema}
+
 
     @functools.cache
     def _get_generic_description(
